@@ -62,10 +62,10 @@ time_monitor (gpointer data)
         app_name = g_get_application_name ();
         if (app_name == NULL)
                 app_name = g_get_prgname ();
-        g_print ("%s couldn't process file: '%s'\n"
-                 "Reason: Took too much time to process.\n",
-                 app_name,
-                 (const char *) data);
+        g_printerr ("%s couldn't process file: '%s'\n"
+                    "Reason: Took too much time to process.\n",
+                    app_name,
+                    (const char *) data);
 
         exit (0);
 }
@@ -174,34 +174,6 @@ atril_thumbnail_pngenc_get (EvDocument *document, const char *thumbnail, int siz
 	g_object_unref (page);
 	
 	if (pixbuf != NULL) {
-		const char *overlaid_icon_name = NULL;
-
-		if (overlaid_icon_name) {
-			GdkPixbuf *overlaid_pixbuf;
-
-			gchar *overlaid_icon_path = g_strdup_printf ("%s/%s", ATRILDATADIR, overlaid_icon_name);
-			overlaid_pixbuf = gdk_pixbuf_new_from_file (overlaid_icon_path, NULL);
-			g_free (overlaid_icon_path);
-			if (overlaid_pixbuf != NULL) {
-				int delta_height, delta_width;
-				
-				delta_width = gdk_pixbuf_get_width (pixbuf) -
-					gdk_pixbuf_get_width (overlaid_pixbuf);
-				delta_height = gdk_pixbuf_get_height (pixbuf) -
-					gdk_pixbuf_get_height (overlaid_pixbuf);
-				
-				gdk_pixbuf_composite (overlaid_pixbuf, pixbuf,
-						      delta_width, delta_height,
-						      gdk_pixbuf_get_width (overlaid_pixbuf),
-						      gdk_pixbuf_get_height (overlaid_pixbuf),
-						      delta_width, delta_height,
-						      1, 1,
-						      GDK_INTERP_NEAREST, 100);
-				
-				g_object_unref  (overlaid_pixbuf);
-			}
-		}
-		
 		if (gdk_pixbuf_save (pixbuf, thumbnail, "png", NULL, NULL)) {
 			g_object_unref  (pixbuf);
 			return TRUE;
@@ -271,7 +243,7 @@ main (int argc, char *argv[])
 	g_option_context_free (context);
 
 	if (size < 1) {
-		g_print ("Size cannot be smaller than 1 pixel\n");
+		g_printerr ("Size cannot be smaller than 1 pixel\n");
 		return -1;
 	}
 
